"""
Module :mod:`hermite_functions._hermite_largest_extrema_spline`

This file is auto-generated by the script ``auxiliary_scripts/02_hermite_functions_largest_extremum.py``.

This module stores the B-spline specifications for the xy-positions of the largest
extrema (= outermost maximum/minimum) of the first ``100176`` Hermite functions.

For both x and y, the splines are quintic B-splines with ``873`` and ``872`` knots
and their maximum absolute relative error is ``1.00e-12`` with respect to a numerical
optimisation which itself is the limiting factor for the accuracy.

For diagnostic plots that show the fit quality, please see
``auxiliary_scripts/02-02_hermite_functions_X_largest_extrema.svg`` and
``auxiliary_scripts/02-03_hermite_functions_Y_largest_extrema.svg``.

"""  # noqa: E501

# === Imports ===

import numpy as np

# === Constants ===

# the specifications of the B-spline for the positions of the largest extrema of the
# Hermite functions

# --- The X-positions of the largest extrema ---

HERMITE_LARGEST_EXTREMA_MAX_ORDER = 100176
X_HERMITE_LARGEST_EXTREMA_SPLINE_TCK = (
    np.array(
        [
            1.0,
            1.0,
            1.0,
            1.0,
            1.0,
            1.0,
            4.0,
            5.0,
            6.0,
            7.0,
            8.0,
            9.0,
            10.0,
            11.0,
            12.0,
            13.0,
            14.0,
            15.0,
            16.0,
            17.0,
            18.0,
            19.0,
            20.0,
            21.0,
            22.0,
            23.0,
            24.0,
            25.0,
            26.0,
            27.0,
            28.0,
            29.0,
            30.0,
            31.0,
            32.0,
            33.0,
            34.0,
            35.0,
            36.0,
            37.0,
            38.0,
            39.0,
            40.0,
            41.0,
            42.0,
            43.0,
            44.0,
            45.0,
            46.0,
            47.0,
            48.0,
            49.0,
            50.0,
            51.0,
            52.0,
            53.0,
            54.0,
            55.0,
            56.0,
            57.0,
            58.0,
            59.0,
            60.0,
            61.0,
            62.0,
            63.0,
            64.0,
            65.0,
            66.0,
            67.0,
            68.0,
            69.0,
            70.0,
            71.0,
            72.0,
            73.0,
            74.0,
            75.0,
            76.0,
            77.0,
            78.0,
            79.0,
            80.0,
            81.0,
            82.0,
            83.0,
            84.0,
            85.0,
            86.0,
            87.0,
            88.0,
            89.0,
            90.0,
            91.0,
            92.0,
            93.0,
            94.0,
            95.0,
            96.0,
            97.0,
            98.0,
            99.0,
            100.0,
            102.0,
            104.0,
            106.0,
            108.0,
            110.0,
            112.0,
            114.0,
            116.0,
            118.0,
            120.0,
            122.0,
            124.0,
            126.0,
            128.0,
            130.0,
            132.0,
            134.0,
            136.0,
            138.0,
            140.0,
            142.0,
            144.0,
            146.0,
            148.0,
            150.0,
            152.0,
            154.0,
            156.0,
            158.0,
            160.0,
            162.0,
            164.0,
            166.0,
            168.0,
            170.0,
            172.0,
            174.0,
            176.0,
            178.0,
            180.0,
            182.0,
            184.0,
            186.0,
            188.0,
            190.0,
            192.0,
            194.0,
            196.0,
            198.0,
            200.0,
            202.0,
            204.0,
            206.0,
            208.0,
            210.0,
            212.0,
            214.0,
            216.0,
            218.0,
            220.0,
            222.0,
            224.0,
            226.0,
            228.0,
            230.0,
            232.0,
            234.0,
            236.0,
            238.0,
            240.0,
            242.0,
            244.0,
            246.0,
            248.0,
            250.0,
            254.0,
            258.0,
            262.0,
            266.0,
            270.0,
            274.0,
            278.0,
            282.0,
            286.0,
            290.0,
            294.0,
            298.0,
            302.0,
            306.0,
            310.0,
            314.0,
            318.0,
            322.0,
            326.0,
            330.0,
            334.0,
            338.0,
            342.0,
            346.0,
            350.0,
            354.0,
            358.0,
            362.0,
            366.0,
            370.0,
            374.0,
            378.0,
            382.0,
            386.0,
            390.0,
            394.0,
            398.0,
            402.0,
            406.0,
            410.0,
            414.0,
            418.0,
            422.0,
            426.0,
            430.0,
            434.0,
            438.0,
            442.0,
            446.0,
            450.0,
            454.0,
            458.0,
            462.0,
            466.0,
            470.0,
            474.0,
            478.0,
            482.0,
            486.0,
            490.0,
            494.0,
            498.0,
            500.0,
            508.0,
            516.0,
            524.0,
            532.0,
            540.0,
            548.0,
            556.0,
            564.0,
            572.0,
            580.0,
            588.0,
            596.0,
            604.0,
            612.0,
            620.0,
            628.0,
            636.0,
            644.0,
            652.0,
            660.0,
            668.0,
            676.0,
            684.0,
            692.0,
            700.0,
            708.0,
            716.0,
            724.0,
            732.0,
            740.0,
            748.0,
            756.0,
            764.0,
            772.0,
            780.0,
            788.0,
            796.0,
            804.0,
            812.0,
            820.0,
            828.0,
            836.0,
            844.0,
            852.0,
            860.0,
            868.0,
            876.0,
            884.0,
            892.0,
            900.0,
            908.0,
            916.0,
            924.0,
            932.0,
            940.0,
            948.0,
            956.0,
            964.0,
            972.0,
            980.0,
            988.0,
            996.0,
            1000.0,
            1016.0,
            1032.0,
            1048.0,
            1064.0,
            1080.0,
            1096.0,
            1112.0,
            1128.0,
            1144.0,
            1160.0,
            1176.0,
            1192.0,
            1208.0,
            1224.0,
            1240.0,
            1256.0,
            1272.0,
            1288.0,
            1304.0,
            1320.0,
            1336.0,
            1352.0,
            1368.0,
            1384.0,
            1400.0,
            1416.0,
            1432.0,
            1448.0,
            1464.0,
            1480.0,
            1496.0,
            1512.0,
            1528.0,
            1544.0,
            1560.0,
            1576.0,
            1592.0,
            1608.0,
            1624.0,
            1640.0,
            1656.0,
            1672.0,
            1688.0,
            1704.0,
            1720.0,
            1736.0,
            1752.0,
            1768.0,
            1784.0,
            1800.0,
            1816.0,
            1832.0,
            1848.0,
            1864.0,
            1880.0,
            1896.0,
            1912.0,
            1928.0,
            1944.0,
            1960.0,
            1976.0,
            1992.0,
            2008.0,
            2024.0,
            2040.0,
            2056.0,
            2072.0,
            2088.0,
            2104.0,
            2120.0,
            2136.0,
            2152.0,
            2168.0,
            2184.0,
            2200.0,
            2216.0,
            2232.0,
            2248.0,
            2264.0,
            2280.0,
            2296.0,
            2312.0,
            2328.0,
            2344.0,
            2360.0,
            2376.0,
            2392.0,
            2408.0,
            2424.0,
            2440.0,
            2456.0,
            2472.0,
            2488.0,
            2500.0,
            2532.0,
            2564.0,
            2596.0,
            2628.0,
            2660.0,
            2692.0,
            2724.0,
            2756.0,
            2788.0,
            2820.0,
            2852.0,
            2884.0,
            2916.0,
            2948.0,
            2980.0,
            3012.0,
            3044.0,
            3076.0,
            3108.0,
            3140.0,
            3172.0,
            3204.0,
            3236.0,
            3268.0,
            3300.0,
            3332.0,
            3364.0,
            3396.0,
            3428.0,
            3460.0,
            3492.0,
            3524.0,
            3556.0,
            3588.0,
            3620.0,
            3652.0,
            3684.0,
            3716.0,
            3748.0,
            3780.0,
            3812.0,
            3844.0,
            3876.0,
            3908.0,
            3940.0,
            3972.0,
            4004.0,
            4036.0,
            4068.0,
            4100.0,
            4132.0,
            4164.0,
            4196.0,
            4228.0,
            4260.0,
            4292.0,
            4324.0,
            4356.0,
            4388.0,
            4420.0,
            4452.0,
            4484.0,
            4516.0,
            4548.0,
            4580.0,
            4612.0,
            4644.0,
            4676.0,
            4708.0,
            4740.0,
            4772.0,
            4804.0,
            4836.0,
            4868.0,
            4900.0,
            4932.0,
            4964.0,
            4996.0,
            5000.0,
            5064.0,
            5128.0,
            5192.0,
            5256.0,
            5320.0,
            5384.0,
            5448.0,
            5512.0,
            5576.0,
            5640.0,
            5704.0,
            5768.0,
            5832.0,
            5896.0,
            5960.0,
            6024.0,
            6088.0,
            6152.0,
            6216.0,
            6280.0,
            6344.0,
            6408.0,
            6472.0,
            6536.0,
            6600.0,
            6664.0,
            6728.0,
            6792.0,
            6856.0,
            6920.0,
            6984.0,
            7048.0,
            7112.0,
            7176.0,
            7240.0,
            7304.0,
            7368.0,
            7432.0,
            7496.0,
            7560.0,
            7624.0,
            7688.0,
            7752.0,
            7816.0,
            7880.0,
            7944.0,
            8008.0,
            8072.0,
            8136.0,
            8200.0,
            8264.0,
            8328.0,
            8392.0,
            8456.0,
            8520.0,
            8584.0,
            8648.0,
            8712.0,
            8776.0,
            8840.0,
            8904.0,
            8968.0,
            9032.0,
            9096.0,
            9160.0,
            9224.0,
            9288.0,
            9352.0,
            9416.0,
            9480.0,
            9544.0,
            9608.0,
            9672.0,
            9736.0,
            9800.0,
            9864.0,
            9928.0,
            9992.0,
            10000.0,
            10128.0,
            10256.0,
            10384.0,
            10512.0,
            10640.0,
            10768.0,
            10896.0,
            11024.0,
            11152.0,
            11280.0,
            11408.0,
            11536.0,
            11664.0,
            11792.0,
            11920.0,
            12048.0,
            12176.0,
            12304.0,
            12432.0,
            12560.0,
            12688.0,
            12816.0,
            12944.0,
            13072.0,
            13200.0,
            13328.0,
            13456.0,
            13584.0,
            13712.0,
            13840.0,
            13968.0,
            14096.0,
            14224.0,
            14352.0,
            14480.0,
            14608.0,
            14736.0,
            14864.0,
            14992.0,
            15120.0,
            15248.0,
            15376.0,
            15504.0,
            15632.0,
            15760.0,
            15888.0,
            16016.0,
            16144.0,
            16272.0,
            16400.0,
            16528.0,
            16656.0,
            16784.0,
            16912.0,
            17040.0,
            17168.0,
            17296.0,
            17424.0,
            17552.0,
            17680.0,
            17808.0,
            17936.0,
            18064.0,
            18192.0,
            18320.0,
            18448.0,
            18576.0,
            18704.0,
            18832.0,
            18960.0,
            19088.0,
            19216.0,
            19344.0,
            19472.0,
            19600.0,
            19728.0,
            19856.0,
            19984.0,
            20112.0,
            20240.0,
            20368.0,
            20496.0,
            20624.0,
            20752.0,
            20880.0,
            21008.0,
            21136.0,
            21264.0,
            21392.0,
            21520.0,
            21648.0,
            21776.0,
            21904.0,
            22032.0,
            22160.0,
            22288.0,
            22416.0,
            22544.0,
            22672.0,
            22800.0,
            22928.0,
            23056.0,
            23184.0,
            23312.0,
            23440.0,
            23568.0,
            23696.0,
            23824.0,
            23952.0,
            24080.0,
            24208.0,
            24336.0,
            24464.0,
            24592.0,
            24720.0,
            24848.0,
            24976.0,
            25000.0,
            25256.0,
            25512.0,
            25768.0,
            26024.0,
            26280.0,
            26536.0,
            26792.0,
            27048.0,
            27304.0,
            27560.0,
            27816.0,
            28072.0,
            28328.0,
            28584.0,
            28840.0,
            29096.0,
            29352.0,
            29608.0,
            29864.0,
            30120.0,
            30376.0,
            30632.0,
            30888.0,
            31144.0,
            31400.0,
            31656.0,
            31912.0,
            32168.0,
            32424.0,
            32680.0,
            32936.0,
            33192.0,
            33448.0,
            33704.0,
            33960.0,
            34216.0,
            34472.0,
            34728.0,
            34984.0,
            35240.0,
            35496.0,
            35752.0,
            36008.0,
            36264.0,
            36520.0,
            36776.0,
            37032.0,
            37288.0,
            37544.0,
            37800.0,
            38056.0,
            38312.0,
            38568.0,
            38824.0,
            39080.0,
            39336.0,
            39592.0,
            39848.0,
            40104.0,
            40360.0,
            40616.0,
            40872.0,
            41128.0,
            41384.0,
            41640.0,
            41896.0,
            42152.0,
            42408.0,
            42664.0,
            42920.0,
            43176.0,
            43432.0,
            43688.0,
            43944.0,
            44200.0,
            44456.0,
            44712.0,
            44968.0,
            45224.0,
            45480.0,
            45736.0,
            45992.0,
            46248.0,
            46504.0,
            46760.0,
            47016.0,
            47272.0,
            47528.0,
            47784.0,
            48040.0,
            48296.0,
            48552.0,
            48808.0,
            49064.0,
            49320.0,
            49576.0,
            49832.0,
            50000.0,
            50512.0,
            51024.0,
            51536.0,
            52048.0,
            52560.0,
            53072.0,
            53584.0,
            54096.0,
            54608.0,
            55120.0,
            55632.0,
            56144.0,
            56656.0,
            57168.0,
            57680.0,
            58192.0,
            58704.0,
            59216.0,
            59728.0,
            60240.0,
            60752.0,
            61264.0,
            61776.0,
            62288.0,
            62800.0,
            63312.0,
            63824.0,
            64336.0,
            64848.0,
            65360.0,
            65872.0,
            66384.0,
            66896.0,
            67408.0,
            67920.0,
            68432.0,
            68944.0,
            69456.0,
            69968.0,
            70480.0,
            70992.0,
            71504.0,
            72016.0,
            72528.0,
            73040.0,
            73552.0,
            74064.0,
            74576.0,
            75088.0,
            75600.0,
            76112.0,
            76624.0,
            77136.0,
            77648.0,
            78160.0,
            78672.0,
            79184.0,
            79696.0,
            80208.0,
            80720.0,
            81232.0,
            81744.0,
            82256.0,
            82768.0,
            83280.0,
            83792.0,
            84304.0,
            84816.0,
            85328.0,
            85840.0,
            86352.0,
            86864.0,
            87376.0,
            87888.0,
            88400.0,
            88912.0,
            89424.0,
            89936.0,
            90448.0,
            90960.0,
            91472.0,
            91984.0,
            92496.0,
            93008.0,
            93520.0,
            94032.0,
            94544.0,
            95056.0,
            95568.0,
            96080.0,
            96592.0,
            97104.0,
            97616.0,
            98128.0,
            98640.0,
            100176.0,
            100176.0,
            100176.0,
            100176.0,
            100176.0,
            100176.0,
        ]
    ),
    np.array(
        [
            0.9999999989634524,
            1.4077447209064788,
            1.8049611048167213,
            2.2213730149925266,
            2.6421236001277784,
            3.0685664710983978,
            3.348980273416356,
            3.610323106114207,
            3.8558724807755986,
            4.0881946863597,
            4.309177659405639,
            4.520326424536688,
            4.722830882303259,
            4.917664791828623,
            5.105630604034828,
            5.287401405153873,
            5.463547139949904,
            5.634555936990124,
            5.800849298981188,
            5.962794333075973,
            6.120713032914649,
            6.274889583383892,
            6.425576402075329,
            6.572998790941112,
            6.717358907516992,
            6.858838903538314,
            6.997603624429747,
            7.133802802721157,
            7.26757293459873,
            7.399038847079617,
            7.528315077272718,
            7.655506973610052,
            7.780711730552167,
            7.904019244866459,
            8.02551282295523,
            8.145269884491118,
            8.263362487755007,
            8.379857871374178,
            8.494818833603768,
            8.608304260352858,
            8.720369250459246,
            8.83106566565701,
            8.940442229293385,
            9.048544881518218,
            9.155416944829675,
            9.261099355692123,
            9.365630820672473,
            9.469048020018128,
            9.571385673911339,
            9.672676861616875,
            9.77295282537631,
            9.872243459763189,
            9.97057712030298,
            10.067980866712478,
            10.164480500830454,
            10.260100658154592,
            10.354864874604786,
            10.44879565905576,
            10.541914546539903,
            10.634242174209401,
            10.725798291623919,
            10.816601906851965,
            10.906671148833764,
            10.996023551121574,
            11.084675911806041,
            11.172644353625799,
            11.25994443196285,
            11.346591103036818,
            11.432598782414061,
            11.517981360375014,
            11.60275223326989,
            11.686924325651225,
            11.770510113976924,
            11.8535216479788,
            11.935970570196215,
            12.017868136704465,
            12.099225230645693,
            12.180052389055168,
            12.260359795344572,
            12.340157348198082,
            12.41945455580275,
            12.498260811373012,
            12.576584894762515,
            12.654435772508265,
            12.731821685872548,
            12.808750968578513,
            12.885231545986452,
            12.96127117032584,
            13.036877358991918,
            13.112057424233534,
            13.186818472701251,
            13.261167416954882,
            13.335110981291171,
            13.408655709478063,
            13.481807971214286,
            13.554573968584535,
            13.626959742289223,
            13.698971177074627,
            13.784942574473941,
            13.884607262406469,
            13.99765597620833,
            14.123742706880522,
            14.262491097428695,
            14.399929513507645,
            14.53609433793487,
            14.67102023928087,
            14.804740375470844,
            14.937286417858811,
            15.068688703785778,
            15.19897627508823,
            15.328176971569048,
            15.456317491658801,
            15.583423460871888,
            15.709519487865192,
            15.83462922507611,
            15.958775409273716,
            16.081979934628396,
            16.204263839538417,
            16.325647485857758,
            16.44615032680817,
            16.565791339569724,
            16.684588632624045,
            16.80255982313487,
            16.919721863540875,
            17.036091139418012,
            17.151683524178758,
            17.26651432423115,
            17.3805983809034,
            17.493950046341023,
            17.60658322503323,
            17.71851138475359,
            17.82974757916851,
            17.940304463741803,
            18.05019431353318,
            18.159429037934174,
            18.26802019768412,
            18.375979014676624,
            18.483316395616367,
            18.590042921312435,
            18.696168911817196,
            18.801704352249587,
            18.906658969664782,
            19.011042300378442,
            19.11486339155878,
            19.218131456398787,
            19.32085507773127,
            19.42304277659062,
            19.524702833466478,
            19.62584338279472,
            19.726472245627075,
            19.82659712239113,
            19.926225489554653,
            20.02536465486412,
            20.124021742534865,
            20.22220370827397,
            20.319917341075392,
            20.417169270368603,
            20.51396597052153,
            20.610313766171227,
            20.70621883688792,
            20.801687221869464,
            20.896724824274656,
            20.991337415640984,
            21.085530639576735,
            21.179310016574785,
            21.27268094568905,
            21.3656487130046,
            21.458218483866272,
            21.550395331650726,
            21.642184198712865,
            21.733589937408034,
            21.824617308956494,
            21.915270960147108,
            22.023612369468577,
            22.149372385128142,
            22.29223698196284,
            22.45185150227699,
            22.62782663746271,
            22.802458697514638,
            22.975778028355975,
            23.147813752900095,
            23.318593925812817,
            23.48814560578456,
            23.656494920396234,
            23.82366699872635,
            23.989686316454545,
            24.1545760325883,
            24.31835941797254,
            24.48105787517694,
            24.64269299037407,
            24.803285171842656,
            24.96285439485184,
            25.121419905744162,
            25.27900041767922,
            25.435613997260074,
            25.591278300355206,
            25.746010208931526,
            25.899826446457734,
            26.052742910126643,
            26.204775317942087,
            26.35593863391759,
            26.506247775467322,
            26.6557169878706,
            26.804360078451904,
            26.952190712846157,
            27.099221968770188,
            27.24546671772133,
            27.390937403100978,
            27.535646190016028,
            27.67960490802921,
            27.822825092706164,
            27.96531798306136,
            28.107094538163157,
            28.24816544283194,
            28.38854112200166,
            28.528231740237658,
            28.667247228173895,
            28.805597265064886,
            28.94329131216554,
            29.080338602914182,
            29.21674815832998,
            29.35252879190461,
            29.48768911347491,
            29.622237545214166,
            29.756182304025756,
            29.889531461990302,
            30.02229284994385,
            30.15447420883658,
            30.286083005034087,
            30.417126678102054,
            30.547612409261813,
            30.677547308755013,
            30.806938083536238,
            30.935791932153034,
            31.064114817484626,
            31.179134160300347,
            31.319214739987935,
            31.484015126479953,
            31.673126982766565,
            31.886082742743096,
            32.134679423901105,
            32.381381090352455,
            32.626230351463384,
            32.86926826147678,
            33.11053447530485,
            33.35006697489906,
            33.58790298905609,
            33.82407710054635,
            34.05862516232754,
            34.29157876652725,
            34.522970887832685,
            34.75283208132781,
            34.98119248730464,
            35.20808103258015,
            35.433525811359,
            35.657554039398256,
            35.880192023631004,
            36.101465373421306,
            36.32139875456117,
            36.54001632550647,
            36.757341331744335,
            36.973396503650314,
            37.188203696338775,
            37.40178434939143,
            37.61415917918099,
            37.82534852358383,
            38.03537174576263,
            38.244248153784326,
            38.451996209596935,
            38.658634043958735,
            38.86417921695043,
            39.06864889001569,
            39.27205976337885,
            39.47442809879274,
            39.675769757489824,
            39.87610019735162,
            40.07543449485894,
            40.27378735403328,
            40.4711731226665,
            40.66760579893337,
            40.86309905273362,
            41.05766622287736,
            41.25132034162297,
            41.44407413496923,
            41.635940038147666,
            41.8269302007404,
            42.01705650145615,
            42.20633054502279,
            42.39476369626165,
            42.58236704277222,
            42.76915145591086,
            42.95512755619857,
            43.14030574576501,
            43.32469619641228,
            43.508308881716744,
            43.69115353349307,
            43.87323971615471,
            44.05457688604836,
            44.21711412565714,
            44.415067675048014,
            44.647953801669495,
            44.91519783329328,
            45.21613740224992,
            45.56744635013664,
            45.91607909965269,
            46.262096393007106,
            46.60555595787391,
            46.946513792113024,
            47.28502364361201,
            47.62113753938872,
            47.9549055785967,
            48.28637619553886,
            48.6155961558079,
            48.942610671564076,
            49.26746345504849,
            49.5901967992684,
            49.91085163100939,
            50.229467580664405,
            50.54608303372772,
            50.860735186217376,
            51.17346009813145,
            51.4842927331799,
            51.793267023877945,
            52.10041589755018,
            52.40577125790694,
            52.70936426756242,
            53.01122491528798,
            53.31138265901298,
            53.60986592167942,
            53.90670231851726,
            54.201919193834335,
            54.49554192315317,
            54.78759720872956,
            55.0781086897328,
            55.36710150128469,
            55.65459864730062,
            55.940623458064564,
            56.22519797983841,
            56.50834433731526,
            56.79008363342143,
            57.07043671517864,
            57.34942379032549,
            57.62706465339936,
            57.90337858446953,
            58.17838442787289,
            58.452100577485524,
            58.72454500391586,
            58.99573526273474,
            59.265688510065296,
            59.53442151418537,
            59.80195066809459,
            60.06829200107344,
            60.33346118984114,
            60.597473569355394,
            60.86034414317967,
            61.12208759329423,
            61.38271828997107,
            61.64225030025817,
            61.90069739844426,
            62.15807307092159,
            62.41439053279761,
            62.66966271638733,
            62.923902323259945,
            63.17712174212767,
            63.429333197372344,
            63.680548593501754,
            63.93077964149913,
            64.1800378434174,
            64.4283343857499,
            64.67568040628036,
            64.92208667085256,
            65.16756387623415,
            65.41212221348357,
            65.6557723812868,
            65.89852389336994,
            66.14038710063762,
            66.38137106985704,
            66.62148617636507,
            66.86074091982553,
            67.0991449828666,
            67.33670714250351,
            67.57343636909903,
            67.8093412707284,
            68.04443052628443,
            68.2787122737132,
            68.51219522464353,
            68.7448869135209,
            68.97679593336927,
            69.20792959438381,
            69.43829598241899,
            69.6679025023967,
            69.89675674666334,
            70.11346042538399,
            70.37499063752475,
            70.68083197026766,
            71.03037340990005,
            71.42291535804337,
            71.86874139936381,
            72.31182556064262,
            72.75221783162178,
            73.18996665728615,
            73.6251190659785,
            74.05772070010109,
            74.48781588389653,
            74.91544767137698,
            75.34065789877776,
            75.76348723122037,
            76.18397520858606,
            76.60216028863846,
            77.01807988720763,
            77.43177041973435,
            77.84326733227333,
            78.25260515089654,
            78.65981749738677,
            79.06493711304279,
            79.46799595667696,
            79.86902512993133,
            80.26805500663775,
            80.66511516416837,
            81.0602344342323,
            81.45344115494622,
            81.84476251864254,
            82.23422576682721,
            82.62185675505616,
            83.00768149048218,
            83.39172461514927,
            83.7740107559527,
            84.15456370813317,
            84.53340701352585,
            84.91056309643349,
            85.28605489190662,
            85.6599036841098,
            86.03213137478629,
            86.40275819525074,
            86.77180534922351,
            87.1392922437494,
            87.50523891846763,
            87.86966435018438,
            88.23258739551073,
            88.59402656826771,
            88.95399979560808,
            89.31252484713298,
            89.66961901409685,
            90.02529932305345,
            90.37958240900565,
            90.73248461660943,
            91.0840219598632,
            91.43421015135932,
            91.78306460329864,
            92.13060043443967,
            92.47683248752216,
            92.82177531070572,
            93.1654432262426,
            93.50785019422806,
            93.8490101510327,
            94.18893625735967,
            94.52764239444217,
            94.86514101018535,
            95.2014452850272,
            95.5365676475387,
            95.87052053828324,
            96.20331608360311,
            96.53496624382547,
            96.86548275631759,
            97.19487716789475,
            97.52316082557476,
            97.85034489204772,
            98.17644033384772,
            98.50145795918522,
            98.82540835914645,
            99.14830199693851,
            99.41382588290351,
            99.74288929015884,
            100.13485980069821,
            100.58896495149607,
            101.10430148280143,
            101.73461401901993,
            102.36105141150432,
            102.98368421281577,
            103.60258101140212,
            104.21780825278665,
            104.82943051596301,
            105.43750963846595,
            106.04210822106128,
            106.643283011398,
            107.24109392573813,
            107.83559476135325,
            108.42684129499197,
            109.01488536881276,
            109.59977937133007,
            110.1815725407267,
            110.76031427994533,
            111.3360518463691,
            111.90883149141084,
            112.47869844595323,
            113.04569659514922,
            113.60986890476123,
            114.17125716263402,
            114.7299021616467,
            115.28584375351282,
            115.83912078743501,
            116.38977119581459,
            116.93783204654781,
            117.48333951605424,
            118.02632896067882,
            118.56683492641264,
            119.10489116671089,
            119.64053070665905,
            120.17378576499135,
            120.70468802084113,
            121.2332679762833,
            121.75955658437532,
            122.28358254597647,
            122.8053753235747,
            123.32496298524144,
            123.84237335187186,
            124.35763351786612,
            124.87077008661782,
            125.381809081935,
            125.89077603142552,
            126.39769590888672,
            126.90259323544026,
            127.40549201400262,
            127.9064157872131,
            128.40538765092757,
            128.90243021135882,
            129.39756574493111,
            129.8908159380112,
            130.38220222416385,
            130.871745550609,
            131.35946649034102,
            131.8453852803894,
            132.32952164959602,
            132.8118953008365,
            133.29252481614884,
            133.77142986142746,
            134.2486279017364,
            134.7241378824047,
            135.19797664332233,
            135.6701628547344,
            136.14071275386868,
            136.60964363527097,
            137.07697228164037,
            137.54271373590834,
            138.00688649206657,
            138.4695039180956,
            138.93058261117255,
            139.39013805469892,
            139.84818428454014,
            140.3047375296446,
            140.68017232112126,
            141.1454504510096,
            141.6996730737795,
            142.34175557480802,
            143.07041288292743,
            143.96164374770467,
            144.84739568864532,
            145.72776981853272,
            146.60286237021984,
            147.4727675323375,
            148.33757633525857,
            149.19737733817794,
            150.05225651128862,
            150.90229741229368,
            151.74758127014857,
            152.5881870416282,
            153.42419154261506,
            154.25566949889858,
            155.08269364437754,
            155.9053347731412,
            156.72366184888074,
            157.5377419908015,
            158.34764069474747,
            159.15342166821517,
            159.95514711516168,
            160.75287763587323,
            161.54667235954287,
            162.336588961937,
            163.12268372591362,
            163.90501158988533,
            164.68362617597808,
            165.4585798762439,
            166.22992380793266,
            166.99770799309528,
            167.76198116725098,
            168.52279121498816,
            169.28018456295771,
            170.03420708091323,
            170.78490315803614,
            171.53231655219713,
            172.2764899019306,
            173.01746498140412,
            173.75528270664688,
            174.4899830006348,
            175.22160503275734,
            175.95018756942918,
            176.6757675452985,
            177.39838222205566,
            178.11806744901529,
            178.8348586714586,
            179.54879043145,
            180.25989681039002,
            180.9682108038386,
            181.67376568824668,
            182.3765920137218,
            183.0767235587157,
            183.7741886578928,
            184.46901920821665,
            185.16124362800758,
            185.8508923494931,
            186.53799230458935,
            187.2225732996229,
            187.90466132940227,
            188.58428437224467,
            189.2614683855122,
            189.93623986833438,
            190.60862415843508,
            191.2786464823056,
            191.94633174277263,
            192.61170374732,
            193.27478696911868,
            193.93560434557105,
            194.5941792897336,
            195.2505342989798,
            195.9046917057064,
            196.55667351199395,
            197.2065011293479,
            197.85419595774002,
            198.49977866644815,
            199.1432699424472,
            199.78468987448554,
            200.42405838335876,
            201.0613950134665,
            201.69671900329539,
            202.3300493245661,
            202.96140459568804,
            203.5908032037879,
            204.2182632123629,
            204.8438024303747,
            205.46743838602106,
            206.08918834619624,
            206.70906931843447,
            207.32709805224906,
            207.94329105877225,
            208.5576645814213,
            209.17023468053998,
            209.78101705337116,
            210.39002747039245,
            210.99728077377227,
            211.6027931946257,
            212.2065771885648,
            212.80865138720753,
            213.40902634823905,
            214.00771873913052,
            214.60474158002646,
            215.20010921098768,
            215.79383512837103,
            216.38593292054085,
            216.97641587221472,
            217.5652971381006,
            218.15258967510877,
            218.73830627258317,
            219.3224595515742,
            219.90506195398083,
            220.48612578606657,
            221.06566313579242,
            221.64368602198337,
            222.22020619137493,
            222.70179312898364,
            223.29716268092085,
            224.00539628408154,
            224.82537142692877,
            225.75577317063497,
            226.88645331711973,
            228.01153001072157,
            229.131085291137,
            230.24520013827276,
            231.35395265974873,
            232.45741986473598,
            233.55567630111977,
            234.6487953078429,
            235.73684863959403,
            236.81990488474057,
            237.89803411011093,
            238.97130092786824,
            240.03977192187426,
            241.10351082274087,
            242.16257884937727,
            243.21703812561213,
            244.26694753595677,
            245.31236596955162,
            246.35335009231102,
            247.38995664041755,
            248.42223872153636,
            249.450252644601,
            250.47404842698563,
            251.49367868438657,
            252.50919405270832,
            253.52064308023748,
            254.5280750325842,
            255.53153731228693,
            256.5310759516669,
            257.52673706943824,
            258.5185652556186,
            259.5066044774037,
            260.4908978945086,
            261.4714875663401,
            262.44841528184475,
            263.42172165149407,
            264.391446565273,
            265.3576292525072,
            266.32030844117304,
            267.27952177840245,
            268.23530647299935,
            269.1876990719199,
            270.13673541671767,
            271.08245071851104,
            272.0248795854979,
            272.9640561057702,
            273.90001365148674,
            274.83278513096775,
            275.76240283445946,
            276.68889856272057,
            277.6123035343586,
            278.53264848279974,
            279.44996363147004,
            280.3642787001879,
            281.2756229330273,
            282.18402509945844,
            283.08951350948814,
            283.9921160205377,
            284.89186004717413,
            285.7887725820916,
            286.6828801715332,
            287.5742090058045,
            288.46278474027883,
            289.348632938665,
            290.2317780752018,
            291.11224587208324,
            291.9900579840049,
            292.8652424634912,
            293.73781860970405,
            294.60781213376214,
            295.4752447104354,
            296.34013930512685,
            297.2025178570779,
            298.06240228470193,
            298.91981406452504,
            299.7747744209471,
            300.6273042524571,
            301.47742417262475,
            302.3251545010742,
            303.17051527634663,
            304.0135262535906,
            304.85420692543005,
            305.69257650584507,
            306.5286539306588,
            307.36245794123147,
            308.19400694372604,
            309.0233191324264,
            309.8504125086377,
            310.6753047071652,
            311.4980132788335,
            312.31855545427794,
            313.13694821038035,
            313.95320848114676,
            314.7113802248544,
            315.63020977829046,
            316.7082529245902,
            317.94378218963743,
            319.334805960595,
            320.93372131015235,
            322.52471342649613,
            324.1078981614854,
            325.6833903049027,
            327.25130017935373,
            328.8117360673532,
            330.3648046712937,
            331.91060837505967,
            333.44924941987057,
            334.98082512402016,
            336.5054324281425,
            338.0231664517205,
            339.53411646796,
            341.0383776938316,
            342.5360324499269,
            344.02717168406576,
            345.51187655498484,
            346.99023144035687,
            348.4623160478414,
            349.92821058454774,
            351.38799062141504,
            352.84173486786153,
            354.28951484619176,
            355.7314048687788,
            357.1674759471698,
            358.5977972390179,
            360.02243882582434,
            361.4414662184039,
            362.85494598666077,
            364.262943102363,
            365.66551971204046,
            367.0627394044598,
            368.4546615548752,
            369.84134736206664,
            371.222854448031,
            372.59924094138324,
            373.9705632127498,
            375.33687661165186,
            376.69823598387876,
            378.0546944290806,
            379.40630477793036,
            380.75311842459905,
            382.09518631081505,
            383.43255804894153,
            384.76528267566897,
            386.09340833055813,
            387.41698220231865,
            388.73605088021486,
            390.05065995146845,
            391.36085443266984,
            392.6666784298428,
            393.96817543066464,
            395.26538813471143,
            396.5583586031928,
            397.8471281544308,
            399.13173748947503,
            400.4122266273446,
            401.68863495997954,
            402.96100125657034,
            404.22936366894993,
            405.49375976395237,
            406.7542265091424,
            408.01080032781226,
            409.26351702814844,
            410.5124119994501,
            411.75751979790556,
            412.99887515700954,
            414.23651062118364,
            415.4704620923156,
            416.7007567281915,
            417.92743548097883,
            419.15052158826194,
            420.37005155468984,
            421.5860539517638,
            422.7985601890191,
            424.007599830366,
            425.21320261767113,
            426.4153976177929,
            427.61421359600513,
            428.8096788710101,
            430.00182139164247,
            431.1906686952918,
            432.37624797587677,
            433.5585860147365,
            434.7377092693618,
            435.9136437941765,
            437.08641535777105,
            438.25604930303956,
            439.42257071891254,
            440.58600425475134,
            441.74637442961216,
            443.3666374052703,
            444.7500063405889,
            445.89909283669414,
            446.8160054447313,
            447.50237413373765,
            0.0,
            0.0,
            0.0,
            0.0,
            0.0,
            0.0,
        ]
    ),
    5,
)

# --- the Y-positions of the largest extrema ---

Y_HERMITE_LARGEST_EXTREMA_SPLINE_TCK = (
    np.array(
        [
            1.0,
            1.0,
            1.0,
            1.0,
            1.0,
            1.0,
            3.0,
            5.0,
            6.0,
            7.0,
            8.0,
            9.0,
            10.0,
            11.0,
            12.0,
            13.0,
            14.0,
            15.0,
            16.0,
            17.0,
            18.0,
            19.0,
            20.0,
            21.0,
            22.0,
            23.0,
            24.0,
            25.0,
            26.0,
            27.0,
            28.0,
            29.0,
            30.0,
            31.0,
            32.0,
            33.0,
            34.0,
            35.0,
            36.0,
            37.0,
            38.0,
            39.0,
            40.0,
            41.0,
            42.0,
            43.0,
            44.0,
            45.0,
            46.0,
            47.0,
            48.0,
            49.0,
            50.0,
            51.0,
            52.0,
            53.0,
            54.0,
            55.0,
            56.0,
            57.0,
            58.0,
            59.0,
            60.0,
            61.0,
            62.0,
            63.0,
            64.0,
            65.0,
            66.0,
            67.0,
            68.0,
            69.0,
            70.0,
            71.0,
            72.0,
            73.0,
            74.0,
            75.0,
            76.0,
            77.0,
            78.0,
            79.0,
            80.0,
            81.0,
            82.0,
            83.0,
            84.0,
            85.0,
            86.0,
            87.0,
            88.0,
            89.0,
            90.0,
            91.0,
            92.0,
            93.0,
            94.0,
            95.0,
            96.0,
            97.0,
            98.0,
            99.0,
            100.0,
            102.0,
            104.0,
            106.0,
            108.0,
            110.0,
            112.0,
            114.0,
            116.0,
            118.0,
            120.0,
            122.0,
            124.0,
            126.0,
            128.0,
            130.0,
            132.0,
            134.0,
            136.0,
            138.0,
            140.0,
            142.0,
            144.0,
            146.0,
            148.0,
            150.0,
            152.0,
            154.0,
            156.0,
            158.0,
            160.0,
            162.0,
            164.0,
            166.0,
            168.0,
            170.0,
            172.0,
            174.0,
            176.0,
            178.0,
            180.0,
            182.0,
            184.0,
            186.0,
            188.0,
            190.0,
            192.0,
            194.0,
            196.0,
            198.0,
            200.0,
            202.0,
            204.0,
            206.0,
            208.0,
            210.0,
            212.0,
            214.0,
            216.0,
            218.0,
            220.0,
            222.0,
            224.0,
            226.0,
            228.0,
            230.0,
            232.0,
            234.0,
            236.0,
            238.0,
            240.0,
            242.0,
            244.0,
            246.0,
            248.0,
            250.0,
            254.0,
            258.0,
            262.0,
            266.0,
            270.0,
            274.0,
            278.0,
            282.0,
            286.0,
            290.0,
            294.0,
            298.0,
            302.0,
            306.0,
            310.0,
            314.0,
            318.0,
            322.0,
            326.0,
            330.0,
            334.0,
            338.0,
            342.0,
            346.0,
            350.0,
            354.0,
            358.0,
            362.0,
            366.0,
            370.0,
            374.0,
            378.0,
            382.0,
            386.0,
            390.0,
            394.0,
            398.0,
            402.0,
            406.0,
            410.0,
            414.0,
            418.0,
            422.0,
            426.0,
            430.0,
            434.0,
            438.0,
            442.0,
            446.0,
            450.0,
            454.0,
            458.0,
            462.0,
            466.0,
            470.0,
            474.0,
            478.0,
            482.0,
            486.0,
            490.0,
            494.0,
            498.0,
            500.0,
            508.0,
            516.0,
            524.0,
            532.0,
            540.0,
            548.0,
            556.0,
            564.0,
            572.0,
            580.0,
            588.0,
            596.0,
            604.0,
            612.0,
            620.0,
            628.0,
            636.0,
            644.0,
            652.0,
            660.0,
            668.0,
            676.0,
            684.0,
            692.0,
            700.0,
            708.0,
            716.0,
            724.0,
            732.0,
            740.0,
            748.0,
            756.0,
            764.0,
            772.0,
            780.0,
            788.0,
            796.0,
            804.0,
            812.0,
            820.0,
            828.0,
            836.0,
            844.0,
            852.0,
            860.0,
            868.0,
            876.0,
            884.0,
            892.0,
            900.0,
            908.0,
            916.0,
            924.0,
            932.0,
            940.0,
            948.0,
            956.0,
            964.0,
            972.0,
            980.0,
            988.0,
            996.0,
            1000.0,
            1016.0,
            1032.0,
            1048.0,
            1064.0,
            1080.0,
            1096.0,
            1112.0,
            1128.0,
            1144.0,
            1160.0,
            1176.0,
            1192.0,
            1224.0,
            1240.0,
            1256.0,
            1272.0,
            1288.0,
            1304.0,
            1320.0,
            1336.0,
            1352.0,
            1368.0,
            1384.0,
            1400.0,
            1416.0,
            1432.0,
            1448.0,
            1464.0,
            1480.0,
            1496.0,
            1512.0,
            1528.0,
            1544.0,
            1560.0,
            1576.0,
            1592.0,
            1608.0,
            1624.0,
            1640.0,
            1656.0,
            1672.0,
            1688.0,
            1704.0,
            1720.0,
            1736.0,
            1752.0,
            1768.0,
            1784.0,
            1800.0,
            1816.0,
            1832.0,
            1848.0,
            1864.0,
            1880.0,
            1896.0,
            1912.0,
            1928.0,
            1944.0,
            1960.0,
            1976.0,
            1992.0,
            2008.0,
            2024.0,
            2040.0,
            2056.0,
            2072.0,
            2088.0,
            2104.0,
            2120.0,
            2136.0,
            2152.0,
            2168.0,
            2184.0,
            2200.0,
            2216.0,
            2232.0,
            2248.0,
            2264.0,
            2280.0,
            2296.0,
            2312.0,
            2328.0,
            2344.0,
            2360.0,
            2376.0,
            2392.0,
            2408.0,
            2424.0,
            2440.0,
            2456.0,
            2472.0,
            2488.0,
            2500.0,
            2532.0,
            2564.0,
            2596.0,
            2628.0,
            2660.0,
            2692.0,
            2724.0,
            2756.0,
            2788.0,
            2820.0,
            2852.0,
            2884.0,
            2916.0,
            2948.0,
            2980.0,
            3012.0,
            3044.0,
            3076.0,
            3108.0,
            3140.0,
            3172.0,
            3204.0,
            3236.0,
            3268.0,
            3300.0,
            3332.0,
            3364.0,
            3396.0,
            3428.0,
            3460.0,
            3492.0,
            3524.0,
            3556.0,
            3588.0,
            3620.0,
            3652.0,
            3684.0,
            3716.0,
            3748.0,
            3780.0,
            3812.0,
            3844.0,
            3876.0,
            3908.0,
            3940.0,
            3972.0,
            4004.0,
            4036.0,
            4068.0,
            4100.0,
            4132.0,
            4164.0,
            4196.0,
            4228.0,
            4260.0,
            4292.0,
            4324.0,
            4356.0,
            4388.0,
            4420.0,
            4452.0,
            4484.0,
            4516.0,
            4548.0,
            4580.0,
            4612.0,
            4644.0,
            4676.0,
            4708.0,
            4740.0,
            4772.0,
            4804.0,
            4836.0,
            4868.0,
            4900.0,
            4932.0,
            4964.0,
            4996.0,
            5000.0,
            5064.0,
            5128.0,
            5192.0,
            5256.0,
            5320.0,
            5384.0,
            5448.0,
            5512.0,
            5576.0,
            5640.0,
            5704.0,
            5768.0,
            5832.0,
            5896.0,
            5960.0,
            6024.0,
            6088.0,
            6152.0,
            6216.0,
            6280.0,
            6344.0,
            6408.0,
            6472.0,
            6536.0,
            6600.0,
            6664.0,
            6728.0,
            6792.0,
            6856.0,
            6920.0,
            6984.0,
            7048.0,
            7112.0,
            7176.0,
            7240.0,
            7304.0,
            7368.0,
            7432.0,
            7496.0,
            7560.0,
            7624.0,
            7688.0,
            7752.0,
            7816.0,
            7880.0,
            7944.0,
            8008.0,
            8072.0,
            8136.0,
            8200.0,
            8264.0,
            8328.0,
            8392.0,
            8456.0,
            8520.0,
            8584.0,
            8648.0,
            8712.0,
            8776.0,
            8840.0,
            8904.0,
            8968.0,
            9032.0,
            9096.0,
            9160.0,
            9224.0,
            9288.0,
            9352.0,
            9416.0,
            9480.0,
            9544.0,
            9608.0,
            9672.0,
            9736.0,
            9800.0,
            9864.0,
            9928.0,
            9992.0,
            10000.0,
            10128.0,
            10256.0,
            10384.0,
            10512.0,
            10640.0,
            10768.0,
            10896.0,
            11024.0,
            11152.0,
            11280.0,
            11408.0,
            11536.0,
            11664.0,
            11792.0,
            11920.0,
            12048.0,
            12176.0,
            12304.0,
            12432.0,
            12560.0,
            12688.0,
            12816.0,
            12944.0,
            13072.0,
            13200.0,
            13328.0,
            13456.0,
            13584.0,
            13712.0,
            13840.0,
            13968.0,
            14096.0,
            14224.0,
            14352.0,
            14480.0,
            14608.0,
            14736.0,
            14864.0,
            14992.0,
            15120.0,
            15248.0,
            15376.0,
            15504.0,
            15632.0,
            15760.0,
            15888.0,
            16016.0,
            16144.0,
            16272.0,
            16400.0,
            16528.0,
            16656.0,
            16784.0,
            16912.0,
            17040.0,
            17168.0,
            17296.0,
            17424.0,
            17552.0,
            17680.0,
            17808.0,
            17936.0,
            18064.0,
            18192.0,
            18320.0,
            18448.0,
            18576.0,
            18704.0,
            18832.0,
            18960.0,
            19088.0,
            19216.0,
            19344.0,
            19472.0,
            19600.0,
            19728.0,
            19856.0,
            19984.0,
            20112.0,
            20240.0,
            20368.0,
            20496.0,
            20624.0,
            20752.0,
            20880.0,
            21008.0,
            21136.0,
            21264.0,
            21392.0,
            21520.0,
            21648.0,
            21776.0,
            21904.0,
            22032.0,
            22160.0,
            22288.0,
            22416.0,
            22544.0,
            22672.0,
            22800.0,
            22928.0,
            23056.0,
            23184.0,
            23312.0,
            23440.0,
            23568.0,
            23696.0,
            23824.0,
            23952.0,
            24080.0,
            24208.0,
            24336.0,
            24464.0,
            24592.0,
            24720.0,
            24848.0,
            24976.0,
            25000.0,
            25256.0,
            25512.0,
            25768.0,
            26024.0,
            26280.0,
            26536.0,
            26792.0,
            27048.0,
            27304.0,
            27560.0,
            27816.0,
            28072.0,
            28328.0,
            28584.0,
            28840.0,
            29096.0,
            29352.0,
            29608.0,
            29864.0,
            30120.0,
            30376.0,
            30632.0,
            30888.0,
            31144.0,
            31400.0,
            31656.0,
            31912.0,
            32168.0,
            32424.0,
            32680.0,
            32936.0,
            33192.0,
            33448.0,
            33704.0,
            33960.0,
            34216.0,
            34472.0,
            34728.0,
            34984.0,
            35240.0,
            35496.0,
            35752.0,
            36008.0,
            36264.0,
            36520.0,
            36776.0,
            37032.0,
            37288.0,
            37544.0,
            37800.0,
            38056.0,
            38312.0,
            38568.0,
            38824.0,
            39080.0,
            39336.0,
            39592.0,
            39848.0,
            40104.0,
            40360.0,
            40616.0,
            40872.0,
            41128.0,
            41384.0,
            41640.0,
            41896.0,
            42152.0,
            42408.0,
            42664.0,
            42920.0,
            43176.0,
            43432.0,
            43688.0,
            43944.0,
            44200.0,
            44456.0,
            44712.0,
            44968.0,
            45224.0,
            45480.0,
            45736.0,
            45992.0,
            46248.0,
            46504.0,
            46760.0,
            47016.0,
            47272.0,
            47528.0,
            47784.0,
            48040.0,
            48296.0,
            48552.0,
            48808.0,
            49064.0,
            49320.0,
            49576.0,
            49832.0,
            50000.0,
            50512.0,
            51024.0,
            51536.0,
            52048.0,
            52560.0,
            53072.0,
            53584.0,
            54096.0,
            54608.0,
            55120.0,
            55632.0,
            56144.0,
            56656.0,
            57168.0,
            57680.0,
            58192.0,
            58704.0,
            59216.0,
            59728.0,
            60240.0,
            60752.0,
            61264.0,
            61776.0,
            62288.0,
            62800.0,
            63312.0,
            63824.0,
            64336.0,
            64848.0,
            65360.0,
            65872.0,
            66384.0,
            66896.0,
            67408.0,
            67920.0,
            68432.0,
            68944.0,
            69456.0,
            69968.0,
            70480.0,
            70992.0,
            71504.0,
            72016.0,
            72528.0,
            73040.0,
            73552.0,
            74064.0,
            74576.0,
            75088.0,
            75600.0,
            76112.0,
            76624.0,
            77136.0,
            77648.0,
            78160.0,
            78672.0,
            79184.0,
            79696.0,
            80208.0,
            80720.0,
            81232.0,
            81744.0,
            82256.0,
            82768.0,
            83280.0,
            83792.0,
            84304.0,
            84816.0,
            85328.0,
            85840.0,
            86352.0,
            86864.0,
            87376.0,
            87888.0,
            88400.0,
            88912.0,
            89424.0,
            89936.0,
            90448.0,
            90960.0,
            91472.0,
            91984.0,
            92496.0,
            93008.0,
            93520.0,
            94032.0,
            94544.0,
            95056.0,
            95568.0,
            96080.0,
            96592.0,
            97104.0,
            97616.0,
            98128.0,
            98640.0,
            100176.0,
            100176.0,
            100176.0,
            100176.0,
            100176.0,
            100176.0,
        ]
    ),
    np.array(
        [
            0.6442883651134756,
            0.6245199839114788,
            0.6001172111655404,
            0.5822596711700364,
            0.5672943498176553,
            0.5546378097918753,
            0.5458989198687396,
            0.5396588089775846,
            0.534206273383199,
            0.5293744298931518,
            0.5250407660100819,
            0.5211164666241704,
            0.5175336150598387,
            0.5142398929213489,
            0.5111938650512047,
            0.5083623237028754,
            0.5057182009740848,
            0.5032391828846259,
            0.5009066545699783,
            0.4987049372799809,
            0.49662070431039534,
            0.49464253766416905,
            0.4927605825721961,
            0.49096627700089274,
            0.48925213668709566,
            0.4876115829649468,
            0.4860388034343882,
            0.4845286383244051,
            0.483076487056322,
            0.48167823087451256,
            0.4803301683442603,
            0.47902896124287664,
            0.47777158890273247,
            0.4765553094759526,
            0.4753776269020651,
            0.47423626260407786,
            0.47312913112492044,
            0.47205431906724715,
            0.4710100668137587,
            0.46999475260139856,
            0.46900687859533635,
            0.4680450586697299,
            0.46710800765194105,
            0.46619453182383946,
            0.465303520510369,
            0.46443393860848264,
            0.46358481993362105,
            0.4627552612801816,
            0.46194441710431017,
            0.46115149475455536,
            0.4603757501828293,
            0.4596164840797028,
            0.45887303838462373,
            0.4581447931281897,
            0.45743116356965263,
            0.4567315975970761,
            0.45604557336191054,
            0.4553725971231534,
            0.45471220127909084,
            0.45406394256791727,
            0.4534274004193832,
            0.4528021754435701,
            0.452187888042264,
            0.45158417713235377,
            0.4509906989696351,
            0.45040712606425587,
            0.4498331461795018,
            0.44926846140558113,
            0.44871278730309716,
            0.4481658521087882,
            0.4476273959985848,
            0.4470971704039404,
            0.44657493737507814,
            0.44606046898970125,
            0.4455535468009191,
            0.44505396132339375,
            0.44456151155302237,
            0.4440760045189669,
            0.44359725486374707,
            0.4431250844512896,
            0.44265932199927627,
            0.4421998027343213,
            0.44174636806893963,
            0.4412988652978613,
            0.44085714731277353,
            0.4404210723342383,
            0.43999050365886994,
            0.4395653094222012,
            0.43914536237420615,
            0.43873053966787895,
            0.438320722660654,
            0.4379157967251147,
            0.43751565107191254,
            0.4371201785811057,
            0.4367292756432987,
            0.43634284200883944,
            0.43596078064533356,
            0.43558299760222774,
            0.4351346827390252,
            0.43461882225982484,
            0.4340388319756493,
            0.43339846829765405,
            0.43270173655010546,
            0.4320192098789596,
            0.43135034274221534,
            0.4306946200081251,
            0.43005155475261647,
            0.42942068625019253,
            0.42880157814128933,
            0.42819381675561596,
            0.4275970095767067,
            0.4270107838342231,
            0.4264347852099646,
            0.42586867664886247,
            0.42531213726274747,
            0.424764861320021,
            0.42422655731302006,
            0.423696947093987,
            0.42317576507859733,
            0.4226627575039506,
            0.42215768174323814,
            0.42166030566752694,
            0.4211704070535496,
            0.42068777303090804,
            0.420212199569338,
            0.41974349099853664,
            0.41928145956065277,
            0.41882592499308186,
            0.4183767141366714,
            0.4179336605702099,
            0.41749660426839036,
            0.4170653912793833,
            0.4166398734242354,
            0.41621990801351844,
            0.4158053575815138,
            0.4153960896360032,
            0.4149919764226001,
            0.414592894703545,
            0.4141987255491667,
            0.4138093541382422,
            0.4134246695769876,
            0.4130445647175692,
            0.41266893599736193,
            0.41229768327846894,
            0.4119307097013235,
            0.41156792154302285,
            0.41120922808542687,
            0.41085454148758727,
            0.4105037766671961,
            0.41015685118698825,
            0.40981368514620437,
            0.4094742010794009,
            0.4091383238584574,
            0.4088059806001418,
            0.4084771005786341,
            0.4081516151410327,
            0.4078294576289249,
            0.4075105633005827,
            0.40719486926129533,
            0.4068823143905276,
            0.40657283928094784,
            0.40626638617069283,
            0.4059628988876033,
            0.40566232278887565,
            0.4053646047080806,
            0.4050696929024134,
            0.40477753700243163,
            0.4044880879641473,
            0.40420129802428245,
            0.4039171206547012,
            0.40363551052155483,
            0.4033564234457294,
            0.4030798163613026,
            0.4027508134679849,
            0.40237117161738395,
            0.40194292037740936,
            0.4014683187823027,
            0.40094980933943153,
            0.40043984614897915,
            0.39993816268996496,
            0.39944450455122793,
            0.39895862871739374,
            0.3984803028983587,
            0.3980093049171871,
            0.3975454221287909,
            0.3970884508926274,
            0.3966381960698805,
            0.39619447056205404,
            0.3957570948787026,
            0.39532589673116486,
            0.3949007106570948,
            0.39448137766599617,
            0.39406774490799307,
            0.3936596653645758,
            0.39325699755761107,
            0.3928596052744776,
            0.3924673573155466,
            0.3920801272486416,
            0.39169779318483594,
            0.39132023756466733,
            0.39094734695602623,
            0.3905790118652005,
            0.39021512655672075,
            0.38985558888694755,
            0.38950030014109516,
            0.38914916488534135,
            0.3888020908215531,
            0.38845898865479495,
            0.38811977196290764,
            0.3877843570775363,
            0.3874526629672783,
            0.3871246111310334,
            0.38680012549108456,
            0.3864791322987125,
            0.3861615600387054,
            0.3858473393406014,
            0.3855364028953215,
            0.38522868537376753,
            0.3849241233516905,
            0.3846226552353014,
            0.3843242211937071,
            0.38402876309155465,
            0.3837362244258785,
            0.3834465502671479,
            0.3831596872006078,
            0.38287558327141524,
            0.3825941879337723,
            0.38231545199893313,
            0.38203932758882264,
            0.3817657680887391,
            0.38149472810504537,
            0.3812261634229307,
            0.38096003096425923,
            0.38069628875325207,
            0.3804348958743894,
            0.3802017207852255,
            0.37991891441702436,
            0.3795879631633002,
            0.37921062455854837,
            0.3787888896665027,
            0.3783010214250326,
            0.3778211814880375,
            0.37734911978362906,
            0.3768845975964305,
            0.3764273868862803,
            0.37597726967537026,
            0.3755340374613041,
            0.3750974906821621,
            0.3746674382162603,
            0.37424369691444836,
            0.37382609116889026,
            0.37341445250079175,
            0.37300861919180034,
            0.3726084359198081,
            0.3722137534356532,
            0.37182442824713746,
            0.3714403223337328,
            0.3710613028685601,
            0.3706872419685459,
            0.37031801644774487,
            0.3699535075951658,
            0.36959360096292593,
            0.3692381861613406,
            0.36888715667715716,
            0.36854040968771573,
            0.3681978459011897,
            0.3678593693914544,
            0.3675248874522371,
            0.3671943104563376,
            0.36686755171731933,
            0.36654452736778553,
            0.36622515623579727,
            0.3659093597350383,
            0.36559706175235845,
            0.3652881885501327,
            0.3649826686645656,
            0.3646804328196037,
            0.36438141383232286,
            0.36408554653689756,
            0.3637927676988036,
            0.363503015944659,
            0.36321623168788597,
            0.3629323570604834,
            0.362651335849178,
            0.3623731134323062,
            0.3620976367235921,
            0.36182485410830745,
            0.3615547153978709,
            0.3612871717754382,
            0.36102217574264883,
            0.36075968107982037,
            0.36049964279464103,
            0.3602420170831775,
            0.35998676128753376,
            0.35973383385508956,
            0.3594831943050001,
            0.35923480318506423,
            0.3589886220452932,
            0.358769014262628,
            0.35850266059277697,
            0.35819095934414,
            0.3578355639496608,
            0.3574383476121841,
            0.3569788338548018,
            0.35652687326517823,
            0.3560822307766988,
            0.35564468198476956,
            0.35521401252156004,
            0.3547900174608829,
            0.3543725007903537,
            0.3539612748858213,
            0.3534751370944938,
            0.35299790762101235,
            0.3525292562398028,
            0.3520688728138274,
            0.35161646524132595,
            0.35124463581773513,
            0.35087784834891667,
            0.3505159730363395,
            0.3501588849716018,
            0.3498064638835142,
            0.3494585939238055,
            0.349115163443193,
            0.3487760648027002,
            0.3484411941774519,
            0.34811045138481206,
            0.3477837397138255,
            0.3474609657687891,
            0.347142039321151,
            0.3468268731663082,
            0.34651538299774687,
            0.3462074872685736,
            0.34590310708780864,
            0.34560216609317074,
            0.34530459035655475,
            0.3450103082734327,
            0.3447192504764633,
            0.3444313497273109,
            0.34414654085855445,
            0.3438647606546919,
            0.3435859478101822,
            0.3433100428261768,
            0.3430369879636886,
            0.34276672715032613,
            0.34249920594628364,
            0.3422343714517958,
            0.3419721722749998,
            0.3417125584639674,
            0.3414554814465345,
            0.34120089400594933,
            0.34094875018892795,
            0.34069900531880254,
            0.34045161588351447,
            0.3402065395560286,
            0.33996373510554934,
            0.3397231623941971,
            0.339484782312499,
            0.3392485567697509,
            0.3390144486295992,
            0.33878242171219575,
            0.3385524407315091,
            0.33832447129107074,
            0.3380984798317827,
            0.33787443362448527,
            0.337652300734928,
            0.3374320499918733,
            0.337213650977563,
            0.33699707399088225,
            0.33678229003317917,
            0.33656927078082827,
            0.3363579885714888,
            0.33614841637387155,
            0.33594052778062045,
            0.33573429697803303,
            0.33552969873724786,
            0.3353267083936036,
            0.3351253018271468,
            0.3349254554498119,
            0.3347271461947215,
            0.3345303514878533,
            0.33433504925108126,
            0.3341412178705206,
            0.33394883619964977,
            0.3337578835367865,
            0.3335683396085352,
            0.33338018457441754,
            0.333193398998427,
            0.333007963841421,
            0.33282386046587364,
            0.3326410705941577,
            0.3324595763330749,
            0.3322883709514823,
            0.33208248171519994,
            0.33184278223211633,
            0.33157030056438974,
            0.3312662013902978,
            0.3309233323362093,
            0.3305850168277003,
            0.3302511400079573,
            0.32992159126976073,
            0.32959626400701547,
            0.32927505549002334,
            0.3289578666091939,
            0.32864460177584415,
            0.32833516869689233,
            0.328029478289524,
            0.3277274444654805,
            0.3274289840644311,
            0.3271340166712611,
            0.3268424645459004,
            0.32655425244942604,
            0.32626930760213396,
            0.32598755952182407,
            0.32570893996844874,
            0.32543338282872564,
            0.3251608240346953,
            0.3248912014899886,
            0.32462445497545694,
            0.32436052608254795,
            0.32409935814460233,
            0.32384089616047035,
            0.32358508673879205,
            0.3233318780336837,
            0.3230812196775351,
            0.3228330627407025,
            0.3225873596675028,
            0.3223440642260846,
            0.3221031314671529,
            0.3218645176603455,
            0.3216281802791852,
            0.3213940779334383,
            0.3211621703224618,
            0.3209324182459148,
            0.3207047834885648,
            0.3204792288739485,
            0.3202557181382685,
            0.3200342159861736,
            0.31981468798287427,
            0.31959710058906304,
            0.3193814210757574,
            0.31916761755248485,
            0.3189556588770481,
            0.3187455147008741,
            0.318537155380519,
            0.3183305520088519,
            0.3181256763334846,
            0.31792250081257856,
            0.3177209985011882,
            0.3175211431260724,
            0.3173229089859145,
            0.3171262709902551,
            0.31693120460680807,
            0.3167376858592285,
            0.31654569132558935,
            0.31635519806080353,
            0.316166183686159,
            0.31597862626273643,
            0.3157925043693342,
            0.3156077970002917,
            0.31542448366517223,
            0.315242544239957,
            0.3150619590866964,
            0.314882708945267,
            0.3147047749665078,
            0.3145281386981862,
            0.31435278206726264,
            0.31417868735785115,
            0.31400583723411885,
            0.31383421469351563,
            0.31366380309071573,
            0.31352419906771056,
            0.3133516954531864,
            0.3131470075019536,
            0.3129110031817247,
            0.3126446883958564,
            0.3123213213582231,
            0.3120022469160422,
            0.311687356841605,
            0.31137654687992455,
            0.31106971659346366,
            0.3107667691452008,
            0.3104676111633857,
            0.31017215254132696,
            0.3098803063172667,
            0.30959198852076975,
            0.30930711803558664,
            0.3090256164761467,
            0.3087474080648641,
            0.308472419522184,
            0.3082005799531464,
            0.30793182075425907,
            0.3076660754866061,
            0.3074032798628737,
            0.3071433715377633,
            0.30688629016018953,
            0.30663197716733587,
            0.30638037583033556,
            0.30613143107227253,
            0.30588508950918963,
            0.3056412992703815,
            0.30540001005955303,
            0.3051611729781246,
            0.30492474057677865,
            0.30469066671857653,
            0.3044589065911538,
            0.3042294166029562,
            0.30400215439196565,
            0.30377707874311716,
            0.3035541495505048,
            0.3033333278197435,
            0.30311457555041993,
            0.30289785578878653,
            0.3026831325297088,
            0.302470370691408,
            0.3022595361371055,
            0.3020505955569399,
            0.30184351650329994,
            0.30163826737105986,
            0.3014348172842049,
            0.30123313619685216,
            0.30103319474635354,
            0.30083496431840473,
            0.30063841698454874,
            0.3004435254604668,
            0.3002502631490567,
            0.3000586040637381,
            0.2998685228133505,
            0.2996799946161764,
            0.29949299525765855,
            0.2993075010709088,
            0.29912348893956164,
            0.29894093626129403,
            0.29875982092167686,
            0.29858012135103446,
            0.2984018163834643,
            0.29822488538582254,
            0.2980493081333741,
            0.2978750648424312,
            0.29770213617113245,
            0.29753050318407853,
            0.2973601473253887,
            0.29719105044898037,
            0.29702319481538814,
            0.296856562966069,
            0.2966911379296454,
            0.2965269029519719,
            0.2963638417014621,
            0.2962019381695882,
            0.2960411766264359,
            0.2959094778307885,
            0.29574674209124147,
            0.2955536441003406,
            0.2953310021996829,
            0.29507976532766905,
            0.2947747049773125,
            0.29447369304985627,
            0.2941766274047915,
            0.293883409825664,
            0.29359394552768603,
            0.2933081432893286,
            0.29302591498185904,
            0.29274717571973485,
            0.29247184345086147,
            0.29219983902407115,
            0.2919310859388128,
            0.2916655103129487,
            0.2914030406319434,
            0.2911436078571847,
            0.29088714509656843,
            0.2906335876909591,
            0.2903828729716306,
            0.2901349403043078,
            0.28988973093424814,
            0.2896471879143089,
            0.28940725605045686,
            0.2891698818354327,
            0.2889350133139068,
            0.28870260017069643,
            0.2884725934835387,
            0.2882449458063275,
            0.2880196110569619,
            0.28779654444369174,
            0.2875757025207545,
            0.28735704295566245,
            0.28714052470602536,
            0.2869261077817879,
            0.2867137533226004,
            0.2865034235056312,
            0.2862950815707972,
            0.2860886916694729,
            0.28588421894674715,
            0.2856816294683613,
            0.2854808901201391,
            0.28528196870726125,
            0.28508483387156486,
            0.28488945493717227,
            0.28469580214552964,
            0.2845038463517936,
            0.2843135592483137,
            0.2841249131035903,
            0.28393788096493444,
            0.2837524364892265,
            0.28356855392912156,
            0.2833862081911001,
            0.28320537480800173,
            0.2830260297765834,
            0.28284814978244166,
            0.2826717119418633,
            0.2824966939475597,
            0.2823230740227457,
            0.2821508307919409,
            0.28197994348655664,
            0.28181039163437455,
            0.2816421554512138,
            0.2814752152781168,
            0.2813095521974131,
            0.28114514746409197,
            0.28098198286075793,
            0.28082004053366827,
            0.2806593029632987,
            0.28049975306746006,
            0.28034137406113696,
            0.2801841495520178,
            0.28002806344909237,
            0.27987310001023497,
            0.27971924382935753,
            0.2795664797465622,
            0.2794147930127794,
            0.2792641690884058,
            0.2791145937001125,
            0.27896605298115273,
            0.2788185332023842,
            0.27867202097158406,
            0.27852650312947125,
            0.2783819667836234,
            0.27823839933087535,
            0.2780957882514999,
            0.27795412148078846,
            0.27781338699912606,
            0.2776735730862846,
            0.2775346682894042,
            0.2773966612235568,
            0.2772595408540017,
            0.27712329631292115,
            0.27698791680775764,
            0.27685339195035286,
            0.27671971135285683,
            0.2765868649240099,
            0.276454842709348,
            0.2763236348784582,
            0.27619323190161527,
            0.27606362429174436,
            0.27593480279734156,
            0.27580675826734735,
            0.2756794817724422,
            0.2755529644967763,
            0.27542719777127045,
            0.275302173068504,
            0.27517788206207017,
            0.27505431645740636,
            0.2749314682023228,
            0.2748093292973667,
            0.27468789193627163,
            0.2745671484176403,
            0.2744470910908476,
            0.27432771261163,
            0.2742090055077779,
            0.27411014463430183,
            0.2739882184060815,
            0.27384363310074844,
            0.27367688207735413,
            0.2734885398748012,
            0.27326099110113206,
            0.27303587890734426,
            0.27281315339976103,
            0.27259276656589826,
            0.27237467148457783,
            0.27215882290094234,
            0.27194517664841167,
            0.2717336899564727,
            0.27152432122231185,
            0.2713170300581362,
            0.2711117771391355,
            0.27090852435052704,
            0.27070723444964456,
            0.2705078713751547,
            0.27031039992820916,
            0.270114785964771,
            0.2699209960674772,
            0.26972899791740096,
            0.2695387598424535,
            0.2693502511787101,
            0.2691634417726656,
            0.26897830263335504,
            0.2687948050793974,
            0.2686129215271244,
            0.26843262470307894,
            0.26825388841229164,
            0.268076686698808,
            0.26790099453877037,
            0.2677267873699346,
            0.26755404123808774,
            0.2673827327552355,
            0.2672128391119322,
            0.2670443379636755,
            0.26687720760152633,
            0.2667114266800494,
            0.266546974401923,
            0.266383830493999,
            0.26622197502675565,
            0.26606138858565087,
            0.265902052254918,
            0.2657439472996601,
            0.26558705569859564,
            0.2654313595973932,
            0.26527684160026266,
            0.2651234847362386,
            0.2649712722669912,
            0.26482018794130957,
            0.26467021578569067,
            0.26452134010407824,
            0.2643735456585147,
            0.2642268174291527,
            0.26408114069482547,
            0.2639365010853662,
            0.2637928844384076,
            0.26365027706304694,
            0.26350866526336436,
            0.26336803588792623,
            0.26322837576016384,
            0.26308967226284646,
            0.2629519128230647,
            0.26281508509511287,
            0.26267917715751216,
            0.26254417709457,
            0.2624100733698892,
            0.26227685460119593,
            0.26214450959380875,
            0.262013027415585,
            0.2618823973693319,
            0.2617526087634318,
            0.2616236513516322,
            0.26149551495497825,
            0.26136818950564383,
            0.2612416652782054,
            0.26111593254252446,
            0.2609909819004149,
            0.2608668040374963,
            0.26074338983333295,
            0.2606207302381135,
            0.26049881645599265,
            0.26037763991997637,
            0.2602571919100172,
            0.2601374642880187,
            0.2600184485126667,
            0.25990013681935925,
            0.2597825209902541,
            0.2596655933306253,
            0.25954934606272756,
            0.2594337717071441,
            0.2593188626756215,
            0.2592046118261483,
            0.25909101171394544,
            0.25897805550153324,
            0.25886573599488794,
            0.25876172514050844,
            0.25863602067288544,
            0.2584890489235273,
            0.25832131599074903,
            0.258133401797695,
            0.25791866398436325,
            0.25770622533062315,
            0.25749603878223964,
            0.2572880589754008,
            0.25708224166780075,
            0.2568785441726171,
            0.2566769248435067,
            0.25647734320525817,
            0.2562797601620442,
            0.25608413755055026,
            0.25589043816327545,
            0.25569862621481565,
            0.2555086663811305,
            0.2553205248642288,
            0.25513416823321744,
            0.25494956432542626,
            0.25476668174018,
            0.25458548977206946,
            0.25440595880618777,
            0.25422805955998956,
            0.2540517640058165,
            0.25387704433525954,
            0.2537038739149051,
            0.25353222630597755,
            0.25336207616823314,
            0.25319339846744016,
            0.2530261689698375,
            0.25286036385158983,
            0.25269596004278544,
            0.25253293495305734,
            0.25237126641159513,
            0.25221093312003695,
            0.2520519136276668,
            0.2518941878439634,
            0.25173773531076393,
            0.2515825367075288,
            0.2514285725901623,
            0.2512758244165339,
            0.25112427366602874,
            0.25097390269535946,
            0.25082469357797804,
            0.2506766295413596,
            0.25052969355883803,
            0.25038386941182866,
            0.25023914081807475,
            0.2500954922643145,
            0.24995290824647418,
            0.24981137371782733,
            0.24967087395714813,
            0.24953139438574454,
            0.24939292111626102,
            0.249255439987826,
            0.2491189375338374,
            0.24898340056475948,
            0.24884881586146723,
            0.2487151706718196,
            0.24858245263822187,
            0.248450649105793,
            0.24831974850491864,
            0.2481897385731328,
            0.24806060805588337,
            0.24793234537634215,
            0.24780493949913623,
            0.2476783794731293,
            0.24755265453611,
            0.2474277541387649,
            0.24730366799759015,
            0.24718038594711905,
            0.24705789799037176,
            0.2469361943713152,
            0.2468152655476632,
            0.2466951019679181,
            0.24657569458986972,
            0.24645703393478613,
            0.24633911148575746,
            0.2462219182584962,
            0.24610544565378079,
            0.24598968512241984,
            0.2458746285418895,
            0.2457602674751715,
            0.24564659417891452,
            0.24553360038736832,
            0.2454212786239589,
            0.24530962111247284,
            0.24519862040276635,
            0.24508826900960592,
            0.24497855981987934,
            0.24486948548898996,
            0.24476103917503944,
            0.2446532138506062,
            0.24454600263476134,
            0.24439675773955244,
            0.2442699151056116,
            0.24416495049762843,
            0.24408144442626348,
            0.2440190737872104,
            0.0,
            0.0,
            0.0,
            0.0,
            0.0,
            0.0,
        ]
    ),
    5,
)
