"""
Module :mod:`hermite_functions._hermite_largest_roots_spline`

This file is auto-generated by the script ``auxiliary_scripts/01_hermite_functions_largest_zeros.py``.

This module stores the B-spline specifications for the largest zeros (= outermost roots)
of the first ``100176`` Hermite functions.

The spline is a quintic B-spline with ``348`` knots and its maximum absolute relative
error is ``1.00e-11`` with respect to ``scipy.special.roots_hermite``.
It should be noted that ``scipy.special.roots_hermite`` only gives roots whose y-values
have an absolute tolerance of roughly ``1e-8``, so the approximation error is limited
by this reference value and not by the spline itself.

For a diagnostic plot that shows the fit quality, please see
``auxiliary_scripts/01-02_hermite_functions_largest_zeros.svg``.

"""  # noqa: E501

# === Imports ===

import numpy as np

# === Constants ===

# the specifications of the B-spline for the largest zeros of the Hermite functions
HERMITE_LARGEST_ZEROS_MAX_ORDER = 100176
HERMITE_LARGEST_ZEROS_SPLINE_TCK = (
    np.array(
        [
            2.0,
            2.0,
            2.0,
            2.0,
            2.0,
            2.0,
            4.0,
            6.0,
            7.0,
            8.0,
            9.0,
            10.0,
            11.0,
            12.0,
            13.0,
            14.0,
            15.0,
            16.0,
            17.0,
            18.0,
            19.0,
            20.0,
            21.0,
            22.0,
            23.0,
            24.0,
            25.0,
            26.0,
            27.0,
            28.0,
            29.0,
            30.0,
            31.0,
            32.0,
            33.0,
            34.0,
            35.0,
            36.0,
            37.0,
            38.0,
            39.0,
            40.0,
            41.0,
            42.0,
            43.0,
            44.0,
            45.0,
            46.0,
            47.0,
            48.0,
            50.0,
            51.0,
            52.0,
            53.0,
            54.0,
            55.0,
            56.0,
            57.0,
            59.0,
            61.0,
            63.0,
            64.0,
            66.0,
            68.0,
            70.0,
            71.0,
            73.0,
            75.0,
            78.0,
            81.0,
            84.0,
            86.0,
            88.0,
            91.0,
            93.0,
            95.0,
            98.0,
            100.0,
            104.0,
            108.0,
            110.0,
            114.0,
            116.0,
            120.0,
            122.0,
            126.0,
            130.0,
            134.0,
            136.0,
            140.0,
            144.0,
            150.0,
            154.0,
            158.0,
            164.0,
            170.0,
            176.0,
            180.0,
            184.0,
            190.0,
            194.0,
            198.0,
            204.0,
            208.0,
            212.0,
            218.0,
            224.0,
            230.0,
            238.0,
            244.0,
            248.0,
            254.0,
            262.0,
            266.0,
            274.0,
            282.0,
            294.0,
            306.0,
            318.0,
            326.0,
            334.0,
            346.0,
            354.0,
            362.0,
            374.0,
            382.0,
            390.0,
            398.0,
            402.0,
            414.0,
            426.0,
            434.0,
            442.0,
            454.0,
            470.0,
            482.0,
            498.0,
            516.0,
            532.0,
            540.0,
            556.0,
            564.0,
            580.0,
            596.0,
            620.0,
            636.0,
            652.0,
            676.0,
            692.0,
            708.0,
            732.0,
            756.0,
            780.0,
            796.0,
            812.0,
            836.0,
            852.0,
            868.0,
            892.0,
            924.0,
            948.0,
            972.0,
            996.0,
            1016.0,
            1048.0,
            1080.0,
            1096.0,
            1128.0,
            1160.0,
            1208.0,
            1240.0,
            1272.0,
            1320.0,
            1368.0,
            1416.0,
            1448.0,
            1480.0,
            1528.0,
            1560.0,
            1592.0,
            1640.0,
            1704.0,
            1752.0,
            1800.0,
            1848.0,
            1912.0,
            1960.0,
            2024.0,
            2072.0,
            2136.0,
            2184.0,
            2232.0,
            2280.0,
            2344.0,
            2392.0,
            2456.0,
            2500.0,
            2564.0,
            2628.0,
            2724.0,
            2820.0,
            2916.0,
            2980.0,
            3044.0,
            3108.0,
            3140.0,
            3204.0,
            3268.0,
            3364.0,
            3492.0,
            3588.0,
            3684.0,
            3780.0,
            3908.0,
            3972.0,
            4004.0,
            4068.0,
            4132.0,
            4228.0,
            4292.0,
            4356.0,
            4452.0,
            4644.0,
            4772.0,
            4868.0,
            4996.0,
            5128.0,
            5256.0,
            5384.0,
            5576.0,
            5768.0,
            5960.0,
            6088.0,
            6216.0,
            6408.0,
            6536.0,
            6664.0,
            6856.0,
            6984.0,
            7112.0,
            7304.0,
            7496.0,
            7688.0,
            7816.0,
            7944.0,
            8136.0,
            8392.0,
            8584.0,
            8840.0,
            9032.0,
            9224.0,
            9416.0,
            9672.0,
            9864.0,
            10128.0,
            10384.0,
            10512.0,
            10768.0,
            11024.0,
            11408.0,
            11792.0,
            12176.0,
            12432.0,
            12688.0,
            13072.0,
            13584.0,
            13968.0,
            14480.0,
            14864.0,
            15248.0,
            15632.0,
            16144.0,
            16528.0,
            16784.0,
            17040.0,
            17424.0,
            17936.0,
            18320.0,
            19088.0,
            19600.0,
            19984.0,
            20496.0,
            20880.0,
            21392.0,
            21776.0,
            22544.0,
            23440.0,
            24336.0,
            25256.0,
            26024.0,
            26792.0,
            27304.0,
            27816.0,
            28584.0,
            29096.0,
            29608.0,
            30376.0,
            31400.0,
            32168.0,
            32936.0,
            33704.0,
            34728.0,
            35496.0,
            36520.0,
            37288.0,
            38312.0,
            39080.0,
            40616.0,
            41640.0,
            42408.0,
            44200.0,
            45224.0,
            45992.0,
            47528.0,
            49320.0,
            50512.0,
            52048.0,
            53072.0,
            54096.0,
            55120.0,
            55632.0,
            57168.0,
            58704.0,
            59728.0,
            60752.0,
            62288.0,
            64336.0,
            65872.0,
            67920.0,
            69456.0,
            70992.0,
            72528.0,
            74576.0,
            76112.0,
            78160.0,
            79696.0,
            81744.0,
            83280.0,
            86352.0,
            89936.0,
            93520.0,
            97104.0,
            100176.0,
            100176.0,
            100176.0,
            100176.0,
            100176.0,
            100176.0,
        ]
    ),
    np.array(
        [
            0.7071067811865921,
            0.9409712679929694,
            1.3428219696893597,
            1.7533852284830405,
            2.1744981908543877,
            2.6019949215285343,
            2.9351577336485137,
            3.19474809146718,
            3.4393450782633144,
            3.671215010036826,
            3.8921207225386842,
            4.103452012340931,
            4.306332396759997,
            4.501682615123642,
            4.690269234061939,
            4.872737865253928,
            5.049638382033789,
            5.221443500557209,
            5.388563105554981,
            5.55135528516043,
            5.710135024027319,
            5.865181101475296,
            6.016741640745125,
            6.165038611535449,
            6.31027151960442,
            6.452620454391338,
            6.59224862634928,
            6.729304494256445,
            6.863923560630858,
            6.99622989626194,
            7.126337442123253,
            7.254351127074056,
            7.380367832186629,
            7.504477226618271,
            7.626762495308946,
            7.747300975107828,
            7.866164713012537,
            7.983420957841223,
            8.099132594794629,
            8.213358530757676,
            8.326154037078728,
            8.437571055225693,
            8.547658470507384,
            8.656462357034824,
            8.764026199112552,
            8.891664066682178,
            9.017561828314433,
            9.141793145355075,
            9.264425983924957,
            9.385523385037247,
            9.485444246389397,
            9.58440002425583,
            9.682417936900249,
            9.798945154156328,
            9.933341143836373,
            10.084883335024792,
            10.234133449267732,
            10.39958926569432,
            10.562692692722466,
            10.723536203268678,
            10.864576805281938,
            11.021171420098113,
            11.175764821091997,
            11.345390500314213,
            11.52937632955189,
            11.743150738886394,
            11.95310450308047,
            12.159451020918327,
            12.36267523677346,
            12.547502381638209,
            12.714738138092379,
            12.894881892196167,
            13.072571690128932,
            13.262765302723075,
            13.479088010653486,
            13.691877070965752,
            13.915542151255957,
            14.135524969521931,
            14.352494951272815,
            14.539801069191618,
            14.751084585639726,
            14.959681264182024,
            15.1909705961481,
            15.393675620162828,
            15.618622951474535,
            15.840590400136973,
            16.084031723209034,
            16.323959877073378,
            16.583745435796864,
            16.86284836840664,
            17.16026919970554,
            17.452969098221097,
            17.740730888064018,
            18.02381609462012,
            18.302843214563165,
            18.556806241362523,
            18.786748758200496,
            19.03459402954935,
            19.279224925495342,
            19.50091218927874,
            19.740058923890864,
            19.9960009267723,
            20.24891319663061,
            20.537031578412478,
            20.83987709173647,
            21.119776964781163,
            21.396124437183815,
            21.687245278386573,
            21.938885464048962,
            22.205572753807605,
            22.504032814465337,
            22.850545820559766,
            23.226119866163554,
            23.662131672959703,
            24.089981215017534,
            24.51014673207573,
            24.923676963974643,
            25.29953382617976,
            25.639434858464302,
            26.005385381978662,
            26.366158423248194,
            26.6927609177511,
            27.0154114273761,
            27.305268445209958,
            27.592515995007417,
            27.905290321032876,
            28.21457417346205,
            28.52048650477335,
            28.87775799463697,
            29.25807035511862,
            29.633651922274478,
            30.05722438936662,
            30.539665280286435,
            31.04003533196081,
            31.48211031349669,
            31.942882130527913,
            32.34821583416399,
            32.73691880651181,
            33.1213995487971,
            33.59606015264829,
            34.06416691661646,
            34.57135404135044,
            35.11659689755953,
            35.653283463163625,
            36.138489714158574,
            36.660740370217574,
            37.218348960752195,
            37.76811686044058,
            38.309637241821186,
            38.84330101346116,
            39.37011413158179,
            39.85030052603794,
            40.28561010076031,
            40.7553678116514,
            41.29699144978561,
            41.83177317747798,
            42.39707958890663,
            42.99158856088047,
            43.55964397117774,
            44.120990104090524,
            44.71105314022667,
            45.258030218777215,
            45.83336610628613,
            46.45285010304795,
            47.13243251411394,
            47.802389019693344,
            48.52800165464493,
            49.307781184278674,
            50.138975916414104,
            50.957199185359116,
            51.761844744590654,
            52.553622215887195,
            53.334226629545036,
            54.04486639432172,
            54.68841235216954,
            55.382187400101195,
            56.181246683137694,
            56.969325716459196,
            57.80142511241684,
            58.675481377113165,
            59.59045446797695,
            60.43921418394569,
            61.32842275559859,
            62.20462962591119,
            63.119224480034894,
            63.971075396706134,
            64.81149603597069,
            65.59286391740567,
            66.4132215253397,
            67.17635402629702,
            67.9779861547534,
            68.75840401935046,
            69.5759625819053,
            70.38436933217989,
            71.31832370167518,
            72.32895947339901,
            73.4665423256317,
            74.58585166018577,
            75.68781339732723,
            76.69108569898158,
            77.51709240807881,
            78.25368204195648,
            78.98363006072806,
            79.78749073356867,
            80.74250591404225,
            81.8417888882923,
            83.00291927538498,
            84.22307103376338,
            85.50080811717567,
            86.61238645614706,
            87.5636183366542,
            88.43268587652314,
            89.22211913883963,
            89.93478777613355,
            90.6418569269082,
            91.41289094804993,
            92.24685866810594,
            93.34848285339919,
            94.5050524766657,
            95.71333730765413,
            97.0374017782705,
            98.41610420807447,
            99.6488710697148,
            100.86677796153822,
            102.25809115088717,
            103.75434838096356,
            105.34315541296554,
            106.90704440083273,
            108.44724938652327,
            109.96684102843132,
            111.3512066177597,
            112.60562519782025,
            113.95872773821675,
            115.29534960213049,
            116.5074449143676,
            117.81586207841055,
            119.21715122652354,
            120.60278473365581,
            121.97179951587934,
            123.32483023710168,
            124.66381103593501,
            126.09109008443342,
            127.50265328506565,
            129.0969670798157,
            130.76838581164876,
            132.4181809969242,
            133.95271319200512,
            135.56447893878942,
            137.0644049194716,
            138.6521835985547,
            140.3130950041922,
            141.86326582894108,
            143.3974398066079,
            145.0035446017214,
            146.75707098848673,
            148.6631070904995,
            150.88331374857444,
            153.06949443824044,
            155.22329733769624,
            157.34889364548397,
            159.60870485187522,
            161.83742667034636,
            164.34748001484454,
            166.97062870319363,
            169.55217598810145,
            171.94710901602812,
            174.45636765341916,
            176.78599422922355,
            178.94121421929526,
            180.92891588136007,
            182.89552123885022,
            184.84345634480405,
            186.77139231656295,
            189.22304206383396,
            191.90834059932814,
            194.55431423880225,
            197.16488782289372,
            199.7394247501861,
            202.0307320541286,
            204.171158315709,
            206.6624870257815,
            209.493317503681,
            212.76818881489797,
            216.3704211084557,
            220.25780683150577,
            224.07637804049898,
            227.49253140237266,
            230.52567936955342,
            233.39181532383893,
            236.00664208178367,
            238.3789417167766,
            240.94088140616648,
            243.89710669985607,
            246.81844134043928,
            249.90920446996222,
            253.1625161711034,
            256.5747594569161,
            259.74594690958776,
            263.07409512550726,
            266.3594628272414,
            269.79457100139916,
            272.99917585565663,
            276.7243826380531,
            280.3999649581899,
            284.02504799670874,
            288.141472372724,
            292.371195006435,
            296.02265096114047,
            299.9726875789538,
            304.54442321211076,
            308.6618496238813,
            313.05186894210124,
            317.5369486313651,
            321.64116453040265,
            325.2240184176408,
            328.35268787420455,
            331.4555651359676,
            334.83705511130944,
            338.18388798671646,
            341.497152105734,
            345.3702749375958,
            349.4968672392152,
            353.5759867908249,
            358.1808349394775,
            363.00562491186486,
            367.7654260334084,
            372.19057324303594,
            376.8363307174799,
            381.1578385453276,
            385.6971862581359,
            390.18218423209873,
            394.8755698503155,
            399.25756431073313,
            404.3553549407363,
            410.1446049936052,
            416.8375143057715,
            424.14850242979975,
            432.03758457831873,
            438.37422190370654,
            443.00662556471116,
            445.9925982428162,
            447.36547564586334,
            0.0,
            0.0,
            0.0,
            0.0,
            0.0,
            0.0,
        ]
    ),
    5,
)
